==> hive-apache-jdbc-0.13.1-9-sources.jar: io/trino/hive/jdbc/$internal/com/google/common/util/concurrent/ListeningScheduledExecutorService.java <==
/*
 * Copyright (C) 2011 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.trino.hive.jdbc.$internal.com.google.common.util.concurrent;

import io.trino.hive.jdbc.$internal.com.google.common.annotations.Beta;

import java.util.concurrent.ScheduledExecutorService;

/**
 * A {@link ScheduledExecutorService} that returns {@link ListenableFuture}
 * instances from its {@code ExecutorService} methods.  Futures returned by the
 * {@code schedule*} methods, by contrast, need not implement {@code
 * ListenableFuture}.  (To create an instance from an existing {@link
 * ScheduledExecutorService}, call {@link
 * MoreExecutors#listeningDecorator(ScheduledExecutorService)}.
 *
 * <p>TODO(cpovirk): make at least the one-time schedule() methods return a
 * ListenableFuture, too? But then we'll need ListenableScheduledFuture...
 *
 * @author Chris Povirk
 * @since 10.0
 */
@Beta
public interface ListeningScheduledExecutorService
    extends ScheduledExecutorService, ListeningExecutorService {
}

==> hive-apache-jdbc-0.13.1-10-sources.jar: io/trino/hive/jdbc/$internal/com/google/common/util/concurrent/ListeningScheduledExecutorService.java <==
/*
 * Copyright (C) 2011 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.trino.hive.jdbc.\$internal.com.google.common.util.concurrent;

import io.trino.hive.jdbc.\$internal.com.google.common.annotations.Beta;

import java.util.concurrent.ScheduledExecutorService;

/**
 * A {@link ScheduledExecutorService} that returns {@link ListenableFuture}
 * instances from its {@code ExecutorService} methods.  Futures returned by the
 * {@code schedule*} methods, by contrast, need not implement {@code
 * ListenableFuture}.  (To create an instance from an existing {@link
 * ScheduledExecutorService}, call {@link
 * MoreExecutors#listeningDecorator(ScheduledExecutorService)}.
 *
 * <p>TODO(cpovirk): make at least the one-time schedule() methods return a
 * ListenableFuture, too? But then we'll need ListenableScheduledFuture...
 *
 * @author Chris Povirk
 * @since 10.0
 */
@Beta
public interface ListeningScheduledExecutorService
    extends ScheduledExecutorService, ListeningExecutorService {
}
